@@ -75,28 +75,30 @@
 #' autoplot(ames_iter_search, metric = "rmse", type = "performance")
 #' @export
 autoplot.tune_results <-
-  function(object,
-           type = c("marginals", "parameters", "performance"),
-           metric = NULL,
-           eval_time = NULL,
-           width = NULL,
-           call = rlang::current_env(),
-           ...) {
+  function(
+    object,
+    type = c("marginals", "parameters", "performance"),
+    metric = NULL,
+    eval_time = NULL,
+    width = NULL,
+    call = rlang::current_env(),
+    ...
+  ) {
     type <- match.arg(type)
     has_iter <- any(names(object) == ".iter")
     if (!has_iter && type != "marginals") {
-      rlang::abort(paste0("`type = ", type, "` is only used with iterative search results."))
+      cli::cli_abort(
+        "{.code type = {glue::double_quote(type)}} is only used with
+                      iterative search results."
+      )
     }
     pset <- .get_tune_parameters(object)
     if (any(is.na(pset$object))) {
       p_names <- pset$id[is.na(pset$object)]
-      msg <-
-        paste0(
-          "Some parameters do not have corresponding parameter objects ",
-          "and cannot be used with `autoplot()`: ",
-          paste0("'", p_names, "'", collapse = ", ")
-        )
-      rlang::abort(msg)
+      cli::cli_abort(
+        "Some parameters do not have corresponding parameter objects and
+         cannot be used with {.fn autoplot}: {.arg {p_names}}."
+      )
     }
 
     if (type == "parameters") {
@@ -108,12 +110,29 @@ autoplot.tune_results <-
       p <- plot_param_vs_iter(object, call)
     } else {
       if (type == "performance") {
-        p <- plot_perf_vs_iter(object, metric, eval_time = eval_time, width, call)
+        p <- plot_perf_vs_iter(
+          object,
+          metric,
+          eval_time = eval_time,
+          width,
+          call
+        )
       } else {
         if (use_regular_grid_plot(object)) {
-          p <- plot_regular_grid(object, metric = metric, eval_time = eval_time, call, ...)
+          p <- plot_regular_grid(
+            object,
+            metric = metric,
+            eval_time = eval_time,
+            call,
+            ...
+          )
         } else {
-          p <- plot_marginals(object, metric = metric, eval_time = eval_time, call)
+          p <- plot_marginals(
+            object,
+            metric = metric,
+            eval_time = eval_time,
+            call
+          )
         }
       }
     }
@@ -122,7 +141,9 @@ autoplot.tune_results <-
 
 #' @export
 autoplot.resample_results <- function(object, ...) {
-  rlang::abort("There is no `autoplot()` implementation for `resample_results`.")
+  cli::cli_abort(
+    "There is no {.fn autoplot} implementation for {.cls resample_results}."
+  )
 }
 
 # ------------------------------------------------------------------------------
@@ -144,8 +165,13 @@ get_param_columns <- function(x) {
   } else {
     dat <- collect_metrics(x)
     other_names <- c(
-      ".metric", ".estimator", "mean", "n",
-      "std_err", ".iter", ".config"
+      ".metric",
+      ".estimator",
+      "mean",
+      "n",
+      "std_err",
+      ".iter",
+      ".config"
     )
     res <- names(dat)[!(names(dat) %in% other_names)]
   }
@@ -155,7 +181,7 @@ get_param_columns <- function(x) {
 # Use the user-given id for the parameter or the parameter label?
 get_param_label <- function(x, id_val) {
   x <- tibble::as_tibble(x)
-  y <- dplyr::filter(x, id == id_val) %>% dplyr::slice(1)
+  y <- dplyr::filter(x, id == id_val) |> dplyr::slice(1)
   num_param <- sum(x$name == y$name)
   no_special_id <- y$name == y$id
   if (no_special_id && num_param == 1) {
@@ -178,7 +204,7 @@ get_param_label <- function(x, id_val) {
 paste_param_by <- function(x) {
   if (".by" %in% colnames(x)) {
     x <-
-      x %>%
+      x |>
       dplyr::mutate(
         .metric = case_when(
           !is.na(.by) ~ paste0(.metric, "(", .by, ")"),
@@ -197,8 +223,8 @@ is_factorial <- function(x, cutoff = 0.95) {
   p <- ncol(x)
   vals <- purrr::map(x, unique)
   full_fact <-
-    tidyr::crossing(!!!vals) %>%
-    dplyr::full_join(x %>% dplyr::mutate(..obs = 1), by = names(x))
+    tidyr::crossing(!!!vals) |>
+    dplyr::full_join(x |> dplyr::mutate(..obs = 1), by = names(x))
   mean(!is.na(full_fact$..obs)) >= cutoff
 }
 
@@ -218,15 +244,23 @@ is_regular_grid <- function(grid) {
     }
   }
 
-  pct_unique <- purrr::map_int(grid, ~ length(unique(.x))) / num_points
+  pct_unique <- purrr::map_int(grid, \(.x) length(unique(.x))) / num_points
   max_pct_unique <- max(pct_unique, na.rm = TRUE)
   np_ratio <- p / num_points
 
   # Derived from simulation data and C5.0 tree
-  if (max_pct_unique > 1 / 2) res <- FALSE
-  if (max_pct_unique <= 1 / 2 & max_pct_unique <= 1 / 6) res <- TRUE
-  if (max_pct_unique <= 1 / 2 & max_pct_unique > 1 / 6 & np_ratio > 0.05) res <- TRUE
-  if (max_pct_unique <= 1 / 2 & max_pct_unique > 1 / 6 & np_ratio <= 0.05) res <- FALSE
+  if (max_pct_unique > 1 / 2) {
+    res <- FALSE
+  }
+  if (max_pct_unique <= 1 / 2 & max_pct_unique <= 1 / 6) {
+    res <- TRUE
+  }
+  if (max_pct_unique <= 1 / 2 & max_pct_unique > 1 / 6 & np_ratio > 0.05) {
+    res <- TRUE
+  }
+  if (max_pct_unique <= 1 / 2 & max_pct_unique > 1 / 6 & np_ratio <= 0.05) {
+    res <- FALSE
+  }
   res
 }
 
@@ -234,8 +268,8 @@ is_regular_grid <- function(grid) {
 use_regular_grid_plot <- function(x) {
   dat <- collect_metrics(x)
   param_cols <- get_param_columns(x)
-  grd <- dat %>%
-    dplyr::select(all_of(param_cols)) %>%
+  grd <- dat |>
+    dplyr::select(all_of(param_cols)) |>
     distinct()
   is_regular_grid(grd)
 }
@@ -244,7 +278,7 @@ use_regular_grid_plot <- function(x) {
 
 process_autoplot_metrics <- function(x, metric, eval_time) {
   met_set <- .get_tune_metrics(x)
-  any_dyn <- any(purrr::map_lgl(metric, ~ is_dyn(met_set, .x)))
+  any_dyn <- any(purrr::map_lgl(metric, \(.x) is_dyn(met_set, .x)))
 
   x <- estimate_tune_results(x)
 
@@ -255,22 +289,21 @@ process_autoplot_metrics <- function(x, metric, eval_time) {
   # have the same value (if any).
   x <- paste_param_by(x)
 
-  x <- x %>%
-    dplyr::filter(.metric %in% metric) %>%
+  x <- x |>
+    dplyr::filter(.metric %in% metric) |>
     dplyr::filter(!is.na(mean))
 
   num_eval_times <- length(eval_time[!is.na(eval_time)])
 
-  if(any_dyn & num_eval_times > 0) {
-    x <- x %>%
-      dplyr::filter(.eval_time %in% eval_time) %>%
+  if (any_dyn & num_eval_times > 0) {
+    x <- x |>
+      dplyr::filter(.eval_time %in% eval_time) |>
       dplyr::mutate(
-        .metric =
-          dplyr::if_else(
-            condition = !is.na(.eval_time),
-            true = paste0(.metric, " @", format(.eval_time, digits = 5)),
-            false = .metric
-          )
+        .metric = dplyr::if_else(
+          condition = !is.na(.eval_time),
+          true = paste0(.metric, " @", format(.eval_time, digits = 5)),
+          false = .metric
+        )
       )
   }
   x
@@ -278,8 +311,13 @@ process_autoplot_metrics <- function(x, metric, eval_time) {
 
 # ------------------------------------------------------------------------------
 
-plot_perf_vs_iter <- function(x, metric = NULL, eval_time = NULL, width = NULL,
-                              call = rlang::caller_env()) {
+plot_perf_vs_iter <- function(
+  x,
+  metric = NULL,
+  eval_time = NULL,
+  width = NULL,
+  call = rlang::caller_env()
+) {
   if (is.null(width)) {
     width <- max(x$.iter) / 75
   }
@@ -290,8 +328,8 @@ plot_perf_vs_iter <- function(x, metric = NULL, eval_time = NULL, width = NULL,
   x <- process_autoplot_metrics(x, metric, eval_time)
 
   search_iter <-
-    x %>%
-    dplyr::filter(.iter > 0 & std_err > 0) %>%
+    x |>
+    dplyr::filter(.iter > 0 & std_err > 0) |>
     dplyr::mutate(const = ifelse(n > 0, qt(0.975, n), 0))
 
   p <-
@@ -322,14 +360,20 @@ plot_param_vs_iter <- function(x, call = rlang::caller_env()) {
   param_cols <- get_param_columns(x)
   pset <- get_param_object(x)
   if (is.null(pset)) {
-    rlang::abort("`autoplot()` requires objects made with tune version 0.1.0 or later.")
+    cli::cli_abort(
+      "{.fn autoplot} requires objects made with {.pkg tune}
+                    version 0.1.0 or later."
+    )
   }
 
   # ----------------------------------------------------------------------------
   # Collect and filter resampling results
 
   x <- estimate_tune_results(x)
-  is_num <- purrr::map_lgl(x %>% dplyr::select(dplyr::all_of(param_cols)), is.numeric)
+  is_num <- purrr::map_lgl(
+    x |> dplyr::select(dplyr::all_of(param_cols)),
+    is.numeric
+  )
   num_param_cols <- param_cols[is_num]
 
   # ----------------------------------------------------------------------------
@@ -353,8 +397,8 @@ plot_param_vs_iter <- function(x, call = rlang::caller_env()) {
   # Stack numeric columns for filtering
 
   x <-
-    x %>%
-    dplyr::select(.iter, dplyr::all_of(num_param_cols)) %>%
+    x |>
+    dplyr::select(.iter, dplyr::all_of(num_param_cols)) |>
     tidyr::pivot_longer(cols = dplyr::all_of(num_param_cols))
 
   # ------------------------------------------------------------------------------
@@ -366,7 +410,7 @@ plot_param_vs_iter <- function(x, call = rlang::caller_env()) {
     scale_x_continuous(breaks = iter_breaks(x$.iter))
 
   if (length(param_cols) == 1) {
-    p <- p  + ylab(param_cols)
+    p <- p + ylab(param_cols)
   } else {
     p <- p + ylab("") + facet_wrap(~name, scales = "free_y")
   }
@@ -374,11 +418,19 @@ plot_param_vs_iter <- function(x, call = rlang::caller_env()) {
   p
 }
 
-plot_marginals <- function(x, metric = NULL, eval_time = NULL, call = rlang::caller_env()) {
+plot_marginals <- function(
+  x,
+  metric = NULL,
+  eval_time = NULL,
+  call = rlang::caller_env()
+) {
   param_cols <- get_param_columns(x)
   pset <- get_param_object(x)
   if (is.null(pset)) {
-    rlang::abort("`autoplot()` requires objects made with tune version 0.1.0 or later.")
+    cli::cli_abort(
+      "{.fn autoplot} requires objects made with {.pkg tune}
+                   version 0.1.0 or later."
+    )
   }
 
   # ----------------------------------------------------------------------------
@@ -394,24 +446,34 @@ plot_marginals <- function(x, metric = NULL, eval_time = NULL, call = rlang::cal
   # ----------------------------------------------------------------------------
   # Check types of parameters then sort by unique values
 
-  is_num <- purrr::map_lgl(x %>% dplyr::select(dplyr::all_of(param_cols)), is.numeric)
-  num_val <- purrr::map_int(x %>% dplyr::select(dplyr::all_of(param_cols)), ~ length(unique(.x)))
+  is_num <- purrr::map_lgl(
+    x |> dplyr::select(dplyr::all_of(param_cols)),
+    is.numeric
+  )
+  num_val <- purrr::map_int(
+    x |> dplyr::select(dplyr::all_of(param_cols)),
+    \(.x) length(unique(.x))
+  )
 
   if (any(num_val < 2)) {
     rm_param <- param_cols[num_val < 2]
     param_cols <- param_cols[num_val >= 2]
     is_num <- is_num[num_val >= 2]
-    x <- x %>% dplyr::select(-dplyr::all_of(rm_param))
+    x <- x |> dplyr::select(-dplyr::all_of(rm_param))
   }
 
   if (any(!is_num)) {
     num_param_cols <- param_cols[is_num]
     chr_param_cols <- param_cols[!is_num]
     if (length(chr_param_cols) > 1) {
-      rlang::abort("Currently cannot autoplot grids with 2+ non-numeric parameters.")
+      cli::cli_abort(
+        "Currently cannot autoplot grids with 2+ non-numeric parameters."
+      )
     }
     if (length(num_param_cols) == 0) {
-      rlang::abort("Currently cannot autoplot grids with only non-numeric parameters.")
+      cli::cli_abort(
+        "Currently cannot autoplot grids with only non-numeric parameters."
+      )
     }
     num_val <- num_val[param_cols %in% chr_param_cols]
     names(num_val) <- chr_param_cols
@@ -443,9 +505,9 @@ plot_marginals <- function(x, metric = NULL, eval_time = NULL, call = rlang::cal
   # Stack numeric parameters for faceting.
 
   x <-
-    x %>%
-    dplyr::rename(`# resamples` = n) %>%
-    dplyr::select(dplyr::all_of(param_cols), mean, `# resamples`, .metric) %>%
+    x |>
+    dplyr::rename(`# resamples` = n) |>
+    dplyr::select(dplyr::all_of(param_cols), mean, `# resamples`, .metric) |>
     tidyr::pivot_longer(cols = dplyr::all_of(num_param_cols))
 
   # ----------------------------------------------------------------------------
@@ -454,7 +516,12 @@ plot_marginals <- function(x, metric = NULL, eval_time = NULL, call = rlang::cal
 
   if (length(chr_param_cols) > 0) {
     if (is_race) {
-      p <- p + geom_point(aes(col = !!sym(chr_param_cols), alpha = `# resamples`, size = resamples))
+      p <- p +
+        geom_point(aes(
+          col = !!sym(chr_param_cols),
+          alpha = `# resamples`,
+          size = resamples
+        ))
       p <- p + ggplot2::labs(color = chr_param_cols)
     } else {
       p <- p + geom_point(aes(col = !!sym(chr_param_cols)), alpha = .7)
@@ -498,10 +565,13 @@ plot_marginals <- function(x, metric = NULL, eval_time = NULL, call = rlang::cal
 }
 
 
-plot_regular_grid <- function(x,
-                              metric = NULL,
-                              eval_time = NULL,
-                              call = rlang::caller_env(), ...) {
+plot_regular_grid <- function(
+  x,
+  metric = NULL,
+  eval_time = NULL,
+  call = rlang::caller_env(),
+  ...
+) {
   # Collect and filter resampling results
 
   is_race <- inherits(x, "tune_race")
@@ -521,10 +591,13 @@ plot_regular_grid <- function(x,
   param_cols <- get_param_columns(x)
   pset <- get_param_object(x)
   if (is.null(pset)) {
-    rlang::abort("`autoplot()` requires objects made with tune version 0.1.0 or later.")
+    cli::cli_abort(
+      "The {.fn autoplot} function requires objects made with
+                    {.pkg tune} version 0.1.0 or later."
+    )
   }
 
-  grd <- dat %>% dplyr::select(all_of(param_cols))
+  grd <- dat |> dplyr::select(all_of(param_cols))
 
   # ----------------------------------------------------------------------------
   # Determine which parameter goes on the x-axis and their types
@@ -533,7 +606,7 @@ plot_regular_grid <- function(x,
   num_param_cols <- param_cols[is_num]
   chr_param_cols <- param_cols[!is_num]
 
-  num_values <- purrr::map_int(grd[, num_param_cols], ~ length(unique(.x)))
+  num_values <- purrr::map_int(grd[, num_param_cols], \(.x) length(unique(.x)))
   num_values <- sort(num_values, decreasing = TRUE)
 
   if (!any(is_num)) {
@@ -574,9 +647,9 @@ plot_regular_grid <- function(x,
   # ----------------------------------------------------------------------------
 
   dat <-
-    dat %>%
-    dplyr::rename(`# resamples` = n) %>%
-    dplyr::select(dplyr::all_of(param_cols), mean, `# resamples`, .metric) %>%
+    dat |>
+    dplyr::rename(`# resamples` = n) |>
+    dplyr::select(dplyr::all_of(param_cols), mean, `# resamples`, .metric) |>
     tidyr::pivot_longer(cols = dplyr::all_of(x_col))
 
   # ------------------------------------------------------------------------------
@@ -590,9 +663,10 @@ plot_regular_grid <- function(x,
       dat[[col_col]] <- format(dat[[col_col]], ...)
     }
     col_col <- rlang::ensym(col_col)
-    p <- ggplot(dat, aes(value, y = mean,
-      col = {{col_col}}, group = {{col_col}}
-    ))
+    p <- ggplot(
+      dat,
+      aes(value, y = mean, col = {{ col_col }}, group = {{ col_col }})
+    )
     # Since `col_col` has either the parameter id or the parameter label, use
     # is in the key:
 
@@ -606,14 +680,18 @@ plot_regular_grid <- function(x,
       facets <- rlang::quos(!!!facets)
       # faceting variables
       if (multi_metrics) {
-        p <- p + facet_grid(
-          rows = vars(.metric), vars(!!!facets),
-          labeller = ggplot2::labeller(.cols = ggplot2::label_both),
-          scales = "free_y"
-        )
+        p <- p +
+          facet_grid(
+            rows = vars(.metric),
+            vars(!!!facets),
+            labeller = ggplot2::labeller(.cols = ggplot2::label_both),
+            scales = "free_y"
+          )
       } else {
         p <-
-          p + facet_wrap(vars(!!!facets),
+          p +
+          facet_wrap(
+            vars(!!!facets),
             labeller = ggplot2::labeller(.cols = ggplot2::label_both)
           )
       }
@@ -670,4 +748,3 @@ iter_breaks <- function(x, num = 10) {
   names(brks) <- attr(brks, "labels")
   brks
 }
-
