@@ -77,6 +77,14 @@
 #'  change the values. This updated parameter set can be passed to the function
 #'  via the `param_info` argument.
 #'
+#'  The rows of the grid are called tuning parameter _candidates_. Each
+#'  candidate has a unique `.config` value that, for grid search, has the
+#'  pattern `pre{num}_mod{num}_post{num}`. The numbers include a zero when that
+#'  element was static. For example, a value of `pre0_mod3_post4` means no
+#'  preprocessors were tuned and the model and postprocessor(s) had at least
+#'  three and four candidates, respectively. Also, the numbers are zero-padded
+#'  to enable proper sorting.
+#'
 #' @section Performance Metrics:
 #'
 #' To use your own performance metrics, the [yardstick::metric_set()] function
@@ -160,10 +168,14 @@
 #'  sub-models so that, in these cases, not every row in the tuning parameter
 #'  grid has a separate R object associated with it.
 #'
+#' Finally, it is a good idea to include calls to [require()] for packages that
+#' are used in the function. This helps prevent failures when using parallel
+#' processing.
+#'
 #' @template case-weights
 #' @template censored-regression
 #'
-#' @examplesIf tune:::should_run_examples(suggests = "kernlab")
+#' @examplesIf tune:::should_run_examples(suggests = "kernlab") & rlang::is_installed("splines2") && !tune:::is_cran_check()
 #' library(recipes)
 #' library(rsample)
 #' library(parsnip)
@@ -180,12 +192,12 @@
 #' # tuning recipe parameters:
 #'
 #' spline_rec <-
-#'   recipe(mpg ~ ., data = mtcars) %>%
-#'   step_ns(disp, deg_free = tune("disp")) %>%
-#'   step_ns(wt, deg_free = tune("wt"))
+#'   recipe(mpg ~ ., data = mtcars) |>
+#'   step_spline_natural(disp, deg_free = tune("disp")) |>
+#'   step_spline_natural(wt, deg_free = tune("wt"))
 #'
 #' lin_mod <-
-#'   linear_reg() %>%
+#'   linear_reg() |>
 #'   set_engine("lm")
 #'
 #' # manually create a grid
@@ -205,12 +217,12 @@
 #' # tune model parameters only (example requires the `kernlab` package)
 #'
 #' car_rec <-
-#'   recipe(mpg ~ ., data = mtcars) %>%
+#'   recipe(mpg ~ ., data = mtcars) |>
 #'   step_normalize(all_predictors())
 #'
 #' svm_mod <-
-#'   svm_rbf(cost = tune(), rbf_sigma = tune()) %>%
-#'   set_engine("kernlab") %>%
+#'   svm_rbf(cost = tune(), rbf_sigma = tune()) |>
+#'   set_engine("kernlab") |>
 #'   set_mode("regression")
 #'
 #' # Use a space-filling design with 7 points
@@ -231,8 +243,8 @@
 #' # to `tune_grid()`, you can also wrap them up in a workflow and pass
 #' # that along instead (note that this doesn't do any preprocessing to
 #' # the variables, it passes them along as-is).
-#' wf <- workflow() %>%
-#'   add_variables(outcomes = mpg, predictors = everything()) %>%
+#' wf <- workflow() |>
+#'   add_variables(outcomes = mpg, predictors = everything()) |>
 #'   add_model(svm_mod)
 #'
 #' set.seed(3254)
@@ -244,23 +256,27 @@ tune_grid <- function(object, ...) {
 
 #' @export
 tune_grid.default <- function(object, ...) {
-  msg <- paste0(
-    "The first argument to [tune_grid()] should be either ",
-    "a model or workflow."
+  cli::cli_abort(
+    "The first argument to {.fn tune_grid} should be either a model or workflow,
+    not {.obj_type_friendly {object}}."
   )
-  rlang::abort(msg)
 }
 
 #' @export
 #' @rdname tune_grid
-tune_grid.model_spec <- function(object, preprocessor, resamples, ...,
-                                 param_info = NULL, grid = 10, metrics = NULL,
-                                 eval_time = NULL, control = control_grid()) {
+tune_grid.model_spec <- function(
+  object,
+  preprocessor,
+  resamples,
+  ...,
+  param_info = NULL,
+  grid = 10,
+  metrics = NULL,
+  eval_time = NULL,
+  control = control_grid()
+) {
   if (rlang::is_missing(preprocessor) || !is_preprocessor(preprocessor)) {
-    rlang::abort(paste(
-      "To tune a model spec, you must preprocess",
-      "with a formula or recipe"
-    ))
+    cli::cli_abort(tune_pp_msg)
   }
 
   control <- parsnip::condense_control(control, control_grid())
@@ -288,9 +304,16 @@ tune_grid.model_spec <- function(object, preprocessor, resamples, ...,
 
 #' @export
 #' @rdname tune_grid
-tune_grid.workflow <- function(object, resamples, ..., param_info = NULL,
-                               grid = 10, metrics = NULL,
-                               eval_time = NULL, control = control_grid()) {
+tune_grid.workflow <- function(
+  object,
+  resamples,
+  ...,
+  param_info = NULL,
+  grid = 10,
+  metrics = NULL,
+  eval_time = NULL,
+  control = control_grid()
+) {
   empty_ellipses(...)
 
   control <- parsnip::condense_control(control, control_grid())
@@ -298,34 +321,39 @@ tune_grid.workflow <- function(object, resamples, ..., param_info = NULL,
   # Disallow `NULL` grids in `tune_grid()`, as this is the special signal
   # used when no tuning is required
   if (is.null(grid)) {
-    rlang::abort(grid_msg)
+    cli::cli_abort(grid_msg)
   }
 
-  res <-
-    tune_grid_workflow(
-      object,
-      resamples = resamples,
-      grid = grid,
-      metrics = metrics,
-      eval_time = eval_time,
-      pset = param_info,
-      control = control
-    )
+  res <- tune_grid_workflow(
+    object,
+    resamples = resamples,
+    grid = grid,
+    metrics = metrics,
+    eval_time = eval_time,
+    pset = param_info,
+    control = control
+  )
   .stash_last_result(res)
   res
 }
 
 # ------------------------------------------------------------------------------
 
-tune_grid_workflow <- function(workflow,
-                               resamples,
-                               grid = 10,
-                               metrics = NULL,
-                               eval_time = NULL,
-                               pset = NULL,
-                               control = control_grid(),
-                               rng = TRUE,
-                               call = caller_env()) {
+tune_grid_workflow <- function(
+  workflow,
+  resamples,
+  grid = 10,
+  metrics = NULL,
+  eval_time = NULL,
+  pset = NULL,
+  control = control_grid(),
+  rng = TRUE,
+  call = caller_env()
+) {
+  if (!catalog_is_active()) {
+    initialize_catalog(control, workflow = workflow)
+  }
+
   check_rset(resamples)
 
   metrics <- check_metrics_arg(metrics, workflow, call = call)
@@ -349,24 +377,26 @@ tune_grid_workflow <- function(workflow,
 
   # Save rset attributes, then fall back to a bare tibble
   rset_info <- pull_rset_attributes(resamples)
-  resamples <- new_bare_tibble(resamples)
+  split_args <- rsample::.get_split_args(resamples)
 
   resamples <- tune_grid_loop(
     resamples = resamples,
     grid = grid,
     workflow = workflow,
+    param_info = pset,
     metrics = metrics,
     eval_time = eval_time,
-    control = control,
-    rng = rng
+    control = control
   )
 
-  if (is_cataclysmic(resamples)) {
-    rlang::warn("All models failed. Run `show_notes(.Last.tune.result)` for more information.")
-  }
+  y_name <- outcome_names(resamples)
 
-  outcomes <- reduce_all_outcome_names(resamples)
-  resamples[[".all_outcome_names"]] <- NULL
+  if (is_cataclysmic(resamples)) {
+    cli::cli_warn(
+      "All models failed. Run {.code show_notes(.Last.tune.result)} for more
+       information."
+    )
+  }
 
   workflow <- set_workflow(workflow, control)
 
@@ -376,7 +406,7 @@ tune_grid_workflow <- function(workflow,
     metrics = metrics,
     eval_time = eval_time,
     eval_time_target = NULL,
-    outcomes = outcomes,
+    outcomes = y_name,
     rset_info = rset_info,
     workflow = workflow
   )
@@ -418,7 +448,10 @@ set_workflow <- function(workflow, control) {
             "setting `save_workflow = FALSE`."
           )
         cols <- get_tune_colors()
-        msg <- strwrap(msg, prefix = paste0(cols$symbol$info(cli::symbol$info), " "))
+        msg <- strwrap(
+          msg,
+          prefix = paste0(cols$symbol$info(cli::symbol$info), " ")
+        )
         msg <- cols$message$info(paste0(msg, collapse = "\n"))
         cli::cli_bullets(msg)
       }
