@@ -1,11 +1,10 @@
-
 test_that("selecting the first metric", {
   library(yardstick)
 
   met_1 <- metric_set(rmse)
-  tbl_1 <- tibble::as_tibble(met_1)[1,]
+  tbl_1 <- tibble::as_tibble(met_1)[1, ]
   met_2 <- metric_set(rmse, ccc)
-  tbl_2 <- tibble::as_tibble(met_2)[1,]
+  tbl_2 <- tibble::as_tibble(met_2)[1, ]
 
   expect_equal(first_metric(met_1), tbl_1)
   expect_equal(first_metric(met_2), tbl_2)
@@ -34,24 +33,20 @@ test_that("identify survival metrics", {
   library(yardstick)
 
   expect_false(
-    metric_set(rmse) %>%
-      tibble::as_tibble() %>%
+    metric_set(rmse) |>
+      tibble::as_tibble() |>
       tune:::contains_survival_metric()
   )
 
   expect_true(
-    metric_set(brier_survival_integrated) %>%
-      tibble::as_tibble() %>%
+    metric_set(brier_survival_integrated) |>
+      tibble::as_tibble() |>
       tune:::contains_survival_metric()
   )
 
   expect_true(
-    metric_set(brier_survival, concordance_survival) %>%
-      tibble::as_tibble() %>%
+    metric_set(brier_survival, concordance_survival) |>
+      tibble::as_tibble() |>
       tune:::contains_survival_metric()
   )
-
 })
-
-
-
