@@ -3,14 +3,21 @@ test_that("prediction types", {
   expect_equal(tune:::pred_type(roc_auc), "prob")
   expect_equal(tune:::pred_type(rsq), "numeric")
   expect_equal(
-    tune:::pred_type(yardstick::metric_set(yardstick::accuracy, yardstick::roc_auc)),
+    tune:::pred_type(yardstick::metric_set(
+      yardstick::accuracy,
+      yardstick::roc_auc
+    )),
     "unknown"
   )
 })
 
 test_that("metric information", {
   set_1 <- tune:::metrics_info(
-    yardstick::metric_set(yardstick::accuracy, yardstick::kap, yardstick::roc_auc)
+    yardstick::metric_set(
+      yardstick::accuracy,
+      yardstick::kap,
+      yardstick::roc_auc
+    )
   )
   set_2 <- tune:::metrics_info(
     yardstick::metric_set(yardstick::rmse, yardstick::rsq)
